@@ -15,6 +15,7 @@ from z3c.pt.pagetemplate import PageTemplateFile as ChameleonPageTemplateFile
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from App.class_init import InitializeClass
 from Products.PageTemplates.Expressions import getEngine
+from RestrictedPython.Utilities import utility_builtins
 
 from chameleon.tales import StringExpr
 from chameleon.tales import NotExpr
@@ -67,8 +68,10 @@ def cook(self):
 
     if engine is getEngine():
         expression_types = _secure_expression_types
+        builtins = utility_builtins
     else:
         expression_types = _expression_types
+        builtins = {}
 
     if filename is None:
         program = ChameleonPageTemplate(
@@ -81,6 +84,8 @@ def cook(self):
             expression_types=expression_types,
             encoding='utf-8')
 
+    program._v_builtins = builtins
+
     self._v_program = program
     self._v_macros = program.macros
     self._v_cooked = 1
@@ -97,12 +102,6 @@ def cook(self):
         self._v_errors = ()
 
 
-def test(condition, a, b):
-    if condition:
-        return a
-    return b
-
-
 @staticmethod
 def create_interpreter(cls, *args, **kwargs):
     return ChameleonTALInterpreter(*args, **kwargs)
@@ -129,10 +128,8 @@ class ChameleonTALInterpreter(object):
             context['wrapped_repeat'] = context['repeat']
             context['repeat'] = RepeatDict(self.repeat)
 
-            # XXX: This could be implemented as a transform which uses
-            # the turnary operator in place of calls to the test
-            # function.
-            context.setdefault('test', test)
+            # Update context with applicable builtins
+            context.update(self.template._v_builtins)
 
             result = self.template.render(**context)
 
